module saveval_alloc
! 変数の定義
! 変数名の命名規則
! 実数 -> r, 純虚数 -> i, 複素数 -> c
! 平均場 -> b, 擾乱場 -> p
! 時間発展 -> old, new

  use saveval_define

  implicit none

contains

subroutine saveval_allocate()

  use saveval_define

  implicit none

  allocate(x(nx))  ! ベクトル動径座標
  allocate(y(ny))  ! 接線座標

  allocate(xd(nxi))
  allocate(yd(nyi))

  allocate(xi(nxi))
  allocate(yi(nyi))

  allocate(bnd(nx,ny))

end subroutine

end module
